@@ -1,8 +1,10 @@
+import base64
 from ConfigParser import ConfigParser
 import os
 import re
 from StringIO import StringIO
 import sys
+import time
 import tempfile
 
 import requests
@@ -139,11 +141,9 @@ class Cast(object):
       return cls.from_string(fp.read())
 
   @classmethod
-  def from_url(cls, cast_url):
-    """ Create a :class:`Cast` from the given url. """
-    response = requests.get(cast_url)
-    response.raise_for_status()
-    return cls.from_string(response.text)
+  def from_url(cls, cast_url, cache_duration=None):
+    """ Create a :class:`Cast` from the given url and optionally cache locally for given interval. """
+    return cls.from_string(url_content(cast_url, cache_duration))
 
   def __str__(self):
     parser = ConfigParser()
@@ -197,7 +197,8 @@ class CastReader(object):
         if header:
           logger.info(header)
         for msg in msgs:
-            logger.info(msg)
+          for line in msg.split('\n'):
+            logger.info(line)
         if footer:
           logger.info(footer)
 
@@ -257,3 +258,45 @@ def _re_sub_multiline(pattern, repl, string):
     content = '\n'.join(content)
 
   return content
+
+
+def _url_content_cache_file(url):
+  return os.path.join(tempfile.gettempdir(), 'url-content-cache-%s' % base64.urlsafe_b64encode(url))
+
+
+def url_content(url, cache_duration=None, from_cache_on_error=False):
+  """
+  Get content for the given URL
+
+  :param str url: The URL to get content from
+  :param int cache_duration: Optionally cache the content for the given duration to avoid downloading too often.
+  :param bool from_cache_on_error: Return cached content on any HTTP request error if available.
+  """
+  cache_file = _url_content_cache_file(url)
+
+  if cache_duration:
+    if os.path.exists(cache_file):
+      stat = os.stat(cache_file)
+      cached_time = stat.st_mtime
+      if time.time() - cached_time < cache_duration:
+        with open(cache_file) as fp:
+          return fp.read()
+
+  try:
+    response = requests.get(url)
+    response.raise_for_status()
+    content = response.text
+
+  except Exception:
+    if from_cache_on_error and os.path.exists(cache_file):
+      with open(cache_file) as fp:
+        return fp.read()
+    else:
+      raise
+
+
+  if cache_duration or from_cache_on_error:
+    with open(cache_file, 'w') as fp:
+      fp.write(content)
+
+  return content
